function MYOEx88
% MYOEx88  Flow rate problem in Example 8.8 in Munson, Young and Okiishi

% --- Define system components
L = [15  10  5  10  10  10]*0.3048; %  Pipe lengths (m)
D = 0.0625*0.3048*ones(size(L));    %  True pipe diameters, all equal
                                    %     at 0.0625*0.3048 (m)
A = 0.25*pi*D.^2;                   %  Cross sectional area
e = 0.0015e-3*ones(size(L));        %  Roughness for drawn tubing
KL = [1.5  1.5  1.5  1.5  10  2];   %  Minor loss coefficients
Am = A(1)*ones(size(KL));           %  Areas of pipe used with minor loss
                                    %  coefficients are same as pipe area
rho = 998.2;         %  Density of water (kg/m^3) at 20 degrees C
gam = rho*9.81;      %  specific weight of fluid (N/m^3)
mu = 1.002e-3;       %  Dynamic viscosity (kg/m/s) at 20 degrees C
nu = mu/rho;         %  Kinematic viscosity (m^2/s)
dz = -20*0.3048;     %  Inlet is 20ft below outlet
Q = 12*6.309e-5;     %  12 gpm flow rate converted to m^3/s

% --- The pipeLoss function uses root-finding to find head loss at given Q 
[hv,f,hm] = pipeLoss(Q,L,A,D,e,nu,KL,Am);

% --- Print summary of losses
fprintf('\nViscous losses in straight pipe sections\n');
fprintf(' section        Re           f         hL\n');
for k=1:length(L)
  Re = (Q/A(k))*D(k)/nu;
  fprintf('  %3d    %12.2e    %8.4f   %6.3f\n',k,Re,f(k),hv(k));
end

fprintf('\nMinor losses in straight pipe sections\n');
fprintf(' fitting     KL        hm\n');
for k=1:length(KL)
  fprintf('  %3d   %8.2f    %6.3f\n',k,KL(k),hm(k));
end

% --- Total head loss is sum of viscous (major) and minor losses
hLtot = sum(hv) + sum(hm);
fprintf('\nTotal head loss');
fprintf(' = %6.1f (m H20),  %6.1f (ft H20)\n',hLtot,hLtot/0.3048);

% --- Total static pressure difference
p1 = gam*(hLtot-dz);
fprintf('\np1 = %8.0f (Pa) = %8.1f (psi)\n',p1,p1*14.696/101325);
fprintf('\nFlow rate  = %11.3e (m^3/s) = %6.1f (gpm)\n',Q,Q/6.309e-5);
Wp = gam*Q*hLtot;       %  pump power (eta = 1)  (W)
fprintf('Pump power = %6.1f (W) = %6.1f hp\n',Wp,Wp*1.341e-3);
