function [Q,hL,hs] = pipeFlowSolve(Q0,L,A,Dh,e,KL,Am,nu,dz,pc)
% pipeFlowSolve  Balance point for a single pipe with or without a pump
%
% Synopsis:  [Q,hL,hs] = pipeFlowSolve(Q0,L,A,Dh,e,KL,Am,nu,dz,pc)
%
% Input:  Q0 = initial guess at pipe flow rate (m^3/s)
%              If Q0 is a scalar, fzero will try to find a bracket.
%              If Q0 is a two element vector, Q0(1) must be lowest possible
%              flow rate, and Q0(2) must be highest possible flow rate
%         L = vector of pipe lengths
%         A = vector of cross-sectional areas of ducts.  A(1) is area of
%             pipe with length L(1) and hydraulic diameter Dh(1)
%         Dh = vector of pipe diameters
%         e = vector of pipe roughnesses
%         KL = vector of minor loss coefficients
%         Am = vector of areas associated with minor loss coefficients.
%              For a flow rate, Q, through minor loss element 1, the area,
%              Am(1) gives the appropriate velocity from V = Q/Am(1).
%              Thus, different minor loss elements will have different
%              velocities for the same flow rate.  For a sudden expansion
%              the characteristic velocity is the upstream velocity, so
%              Am for that element is the area of the upstream duct.
%         nu = kinematic viscosity of the fluid 
%         dz = change in elevation, z_out - z_in;  dz>0 if outlet is above
%              the inlet;  dz = 0 for closed loop
%         pc = vector of polynomial coefficients defining the pump curve.
%              Note that the polynomial is defined in decreasing power of Q:
%               hs(Q) = pc(1)Q^n + pc(2)*Q^(n-1) + ... + pc(n)*Q + pc(n+1)
%              If there is no pump in the system, use pc = [] (null matrix)
%
% Output: Q  = flow rate through the pipeline
%         hL = head loss in the system
%         hs = shaft work done on the fluid

% --- find balance point
Q = fzero('pipeHeadBal',Q0,optimset('Display','none'),L,A,Dh,e,KL,Am,nu,dz,pc);

if isempty(pc)
  hs = 0;
else
  hs = polyval(pc,Q);     %  compute pump power at the balance point
end
fprintf('\nSystem balance point at\n');
fprintf('\t Q = %8.4f m^3/s    pump head = %6.1f (m)\n',Q,hs);

[hv,hm,f] = pipeLoss(Q,L,A,Dh,e,KL,Am,nu);  %  re-evaluate losses for printout
hL = sum(hv) + sum(hm);                     %  total loss

% --- prepare to print results
... see full listing on disk
