function testPipeLoss
% testPipeLoss  Compute flow loss in a simple, single pipe system

% --- data for straight pipe sections
dsteel = 0.127;       %  diameter of commercial steel pipe used (m)
diron  = 0.102;       %  diameter of cast iron pipe used (m)
epsSteel = 0.045e-3;  %  roughness of steel pipe (m)
epsIron = 0.26e-3;    %  roughness of cast iron pipe (m)

% --- make column vectors with L, D, A, and e data
L = [50; 10; 20; 25; 20];                     %  pipe lengths (m)
D = [dsteel; dsteel; dsteel; diron; dsteel];  %  pipe diameters (m)
A = 0.25*pi*D.^2;                             %  X-sectional areas (m^2)
e = [epsSteel; epsSteel; epsSteel; epsIron; epsSteel];  % roughness

% --- data for minor losses
kelbow = 0.3;
kvalve = 10;
Asteel = 0.25*pi*dsteel^2;  %  cross-sectional area of the steel pipe
Airon = 0.25*pi*diron^2;    %    "    "     "   "    "  "  cast iron pipe
kcontract = contractionLoss(Asteel,Airon);
kexpand = (1 - Airon/Asteel)^2;
KL = [kelbow; kelbow; kvalve; kcontract; kexpand; kvalve];
Am = [Asteel; Asteel; Asteel; Airon;     Airon;   Asteel];

% --- overall elevation change and flow rate
dz = L(2);           %  outlet is above inlet by this amount
Q = 0.05;            %  flow rate (m^3/s)

% --- fluid properties
rho = 999.7;               %  density of water (kg/m^3) at 10 degrees C
mu = 1.307e-3;             %  dynamic viscosity (kg/m/s) at 10 degrees C
nu = mu/rho;               %  kinematic viscosity (m^2/s)

% --- compute head loss
[hv,f,hm] = pipeLoss(Q,L,A,D,e,nu,KL,Am);

% --- print results
fprintf('\nViscous losses in straight pipe sections\n');
fprintf(' section        Re           f         hL\n');
for k=1:length(L)
  Re = (Q/A(k))*D(k)/nu;
  fprintf('  %3d    %12.2e    %8.4f   %6.1f\n',k,Re,f(k),hv(k));
end
fprintf('\nMinor losses in straight pipe sections\n');
fprintf(' fitting     KL        hm\n');
for k=1:length(KL)
  fprintf('  %3d   %8.2f    %6.1f\n',k,KL(k),hm(k));
end
fprintf('\nTotal viscous loss = %6.1f  (m)\n',sum(hv));
fprintf('Total minor loss   = %6.1f  (m)\n',sum(hm));
fprintf('Total head loss    = %6.1f  (m)\n',sum(hm)+sum(hv));
